pub(crate) async fn verify_supports_safe_deposit(
db: &Database,
module_api: &DynModuleApi,
) -> Option<bool>Expand description
Fetches the federation’s wallet module consensus version and records the marker if it supports safe deposits.
Returns None if the version could not be fetched, e.g. while offline.